camelot.camelot.view.fifo

Package camelot :: Package camelot :: Package view :: Module fifo |
[hide private]
[frames] | no frames]

# Module fifo

source code

Classes | [hide private]
| fifo fifo, is the actual cache containing a limited set of copies of row data so the data in fifo, is always immediately accessible to the gui thread, with zero delay as you scroll down the table view, fifo is filled and refilled with data queried from the database